Package: ViSe
Type: Package
Title: Visualizing Sensitivity
Version: 0.1.3
Authors@R: c(person("Erin M.", "Buchanan", role = c("aut", "cre"),
                     email = "buchananlab@gmail.com",
                     comment = c(ORCID = "0000-0002-9689-4189")))
Depends: R (>= 3.1.0)
Imports: stats, ggplot2, methods, dplyr, tidyr, scales, cowplot, shiny
Maintainer: Erin M. Buchanan <buchananlab@gmail.com>
Description: Designed to help the user to determine the sensitivity of an proposed causal effect to unconsidered common causes. Users can create visualizations of sensitivity, effect sizes, and determine which pattern of effects would support a causal claim for between group differences. Number needed to treat formula from Kraemer H.C. & Kupfer D.J. (2006) <doi:10.1016/j.biopsych.2005.09.014>.
License: LGPL-3
Encoding: UTF-8
RoxygenNote: 7.3.2
URL: http://www.aggieerin.com/ViSe/
Suggests: knitr, rmarkdown, plotly
VignetteBuilder: knitr
Collate: 'globals.R' 'adjusted_coef.R' 'apa.R' 'big_donut.R'
        'calculate_d.R' 'd_to_f2.R' 'd_to_nnt.R' 'd_to_r.R'
        'estimate_d.R' 'estimate_r.R' 'noncentral_t.R' 'other_to_d.R'
        'probability_superiority.R' 'proportion_overlap.R'
        'runExample.R' 'visualize_c.R' 'visualize_c_map.R'
        'visualize_effects.R'
NeedsCompilation: no
Packaged: 2024-10-10 01:43:49 UTC; erinbuchanan
Author: Erin M. Buchanan [aut, cre] (<https://orcid.org/0000-0002-9689-4189>)
Repository: CRAN
Date/Publication: 2024-10-10 02:20:02 UTC
Built: R 4.6.0; ; 2026-04-30 05:51:18 UTC; unix
