# Generated by roxygen2: do not edit by hand

export(adjusted_coef)
export(apa)
export(calculate_d)
export(d_to_f2)
export(d_to_nnt)
export(d_to_r)
export(estimate_d)
export(estimate_r)
export(other_to_d)
export(probability_superiority)
export(proportion_overlap)
export(runExample)
export(visualize_c)
export(visualize_c_map)
export(visualize_effects)
import(cowplot)
import(ggplot2)
import(methods)
import(stats)
importFrom(dplyr,"%>%")
importFrom(dplyr,mutate)
importFrom(scales,percent)
importFrom(tidyr,pivot_longer)
